pyCelestia documentation
========================
The Python client for working with the Celestia blockchain platform.

.. image:: https://img.shields.io/badge/python-3.10-blue.svg
   :alt: Python 3.10
   :target: https://www.python.org/downloads/release/python-3100/

.. image:: https://img.shields.io/badge/python-3.11-blue.svg
   :alt: Python 3.11
   :target: https://www.python.org/downloads/release/python-3110/

.. image:: https://img.shields.io/badge/python-3.12-blue.svg
   :alt: Python 3.12
   :target: https://www.python.org/downloads/release/python-3120/

This module provides an interface for interacting with the Celestia Node API. All methods interact with the Celestia Node API via JSON-RPC, providing a flexible and easy-to-integrate solution for developers.

This interface is ideal for developers who want to integrate Celestia Node API interactions into their applications without having to handle the low-level details of RPC requests.


.. toctree::
   :maxdepth: 2
   :caption: Api Documentation:

   node_api

.. toctree::
   :maxdepth: 2
   :caption: Types:

   types
